@@ -98,8 +98,8 @@ def initialize_metadata(Lochness, args,
                     multiple_site_in_a_repo, upenn_redcap)
 
         elif 'redcap' in args.input_sources:
-            id_fieldname = 'chric_record_id'
-            consent_fieldname = 'chric_consent_date'
+            id_fieldname = Lochness['redcap_id_colname']
+            consent_fieldname = Lochness['redcap_consent_colname']
             REDCap.initialize_metadata(
                     Lochness, study_name, id_fieldname, consent_fieldname,
                     multiple_site_in_a_repo, upenn_redcap)
@@ -378,10 +378,14 @@ def listdir(Lochness, d):
 
 def attempt(f, Lochness, *args, **kwargs):
     '''attempt a function call'''
-    # if len(attempt.warnings) >= 5:
-        # # lochness.email.attempts_error(Lochness, attempt)
-        # attempt.warnings = []
-        # raise AttemptsError('too many attempt warnings')
+
+    '''
+    if len(attempt.warnings) >= 5:
+        # lochness.email.attempts_error(Lochness, attempt)
+        attempt.warnings = []
+        raise AttemptsError('too many attempt warnings')
+    '''
+
     try:
         f(Lochness, *args, **kwargs)
     except Exception as e:
