@@ -114,18 +114,22 @@ def write_commands_needed(args: 'argparse',
                        --studies {' '.join(args.studies)} \
                        --source {' '.join(args.sources)} \
                        --lochness_sync_send --s3 \
-                       --debug --continuous\n"
+                       --debug --continuous \
+                       --log-file {args.outdir}/log.txt \
+                       --daily_summary\n"
             elif args.rsync:
                 command = f"sync.py -c {config_loc} \
                         --studies {' '.join(args.studies)} \
                         --source {' '.join(args.sources)} \
                         --lochness_sync_send --rsync \
+                        --log-file {args.outdir}/log.txt \
                         --debug --continuous\n"
             else:
                 command = f"sync.py -c {config_loc} \
                         --studies {' '.join(args.studies)} \
                         --source {' '.join(args.sources)} \
                         --lochness_sync_send --s3 \
+                        --log-file {args.outdir}/log.txt \
                         --debug --continuous\n"
         
         command = re.sub('\s\s+', ' \\\n\t', command)
@@ -151,7 +155,11 @@ def create_keyring_template(keyring_loc: Path, args: object) -> None:
             upenn_api_token = '*****'
 
         template_dict['lochness']['REDCAP'] = {}
+
         template_dict['lochness']['SECRETS'] = {}
+        template_dict['lochness']["email_sender_pw"] = "*****"
+        
+
         for study in args.studies:
             project_name = study[:-2]
             if 'upenn' in args.sources and 'redcap' in args.sources:
@@ -302,6 +310,7 @@ def create_config_template(config_loc: Path, args: object) -> None:
 
     config_example = f'''keyring_file: {args.outdir}/.lochness.enc
 phoenix_root: {args.outdir}/PHOENIX
+project_name: ProNET
 BIDS: True
 pid: {args.outdir}/lochness.pid
 stderr: {args.outdir}/lochness.stderr
@@ -309,10 +318,10 @@ stdout: {args.outdir}/lochness.stdout
 poll_interval: {args.poll_interval}
 ssh_user: {args.ssh_user}
 ssh_host: {args.ssh_host}
-sender: {args.email}
 mindlamp_days_to_pull: 100
 pii_table: {args.pii_csv}
 lochness_sync_history_csv: {args.lochness_sync_history_csv}
+
 '''
 
     if 'rpms' in args.sources:
@@ -365,16 +374,29 @@ AWS_BUCKET_ROOT: TEST_PHOENIX_ROOT_PRONET'''
             actigraphy:
                 - vendor: Insights
                   product: GENEActivQC
-                  data_dir: Actigraphy
-                  pattern: '*.(cwa|csv)'
+                  data_dir: {study}_Actigraphy
+                  pattern: '*'
             eeg:
                    - product: eeg
-                     data_dir: EEG
-                     pattern: '*.(csv|zip)'
+                     data_dir: {study}_EEG
+                     pattern: '*'
+            mri:
+                   - product: mri
+                     data_dir: {study}_MRI
+                     pattern: '*'
             interviews:
-                   - product: offsite_interview
-                     data_dir: Interview_recordings
-                     pattern: '*.(mp4|m4a|m3u|wav)'
+                   - product: open
+                     data_dir: {study}_Interviews/OPEN
+                     out_dir: open
+                     pattern: '*'
+                   - product: psychs
+                     data_dir: {study}_Interviews/PSYCHS
+                     out_dir: psychs
+                     pattern: '*'
+                   - product: transcripts
+                     data_dir: {study}_Interviews/transcripts/Approved
+                     out_dir: transcripts
+                     pattern: '*'
               '''
 
             config_example += line_to_add
@@ -419,6 +441,7 @@ hdd:
         base: /PHOENIX
 admins:
     - {args.email}
+sender: {args.email}
 notify:
     __global__:
         - {args.email}
